==> blender-2.45p1.tgz: share/blender/scripts/help_getting_started.py <==
#!BPY
"""
Name: 'Getting Started'
Blender: 234
Group: 'Help'
Tooltip: 'Help for new users'
"""

__author__ = "Matt Ebb"
__url__ = ("blender", "elysiun")
__version__ = "1.0"
__bpydoc__ = """\
This script opens the user's default web browser at www.blender3d.org's
"Getting Started" page.
"""

# $Id: help_getting_started.py 3396 2004-11-07 16:31:13Z ianwill $
#
# --------------------------------------------------------------------------
# Getting Started Help Menu Item
# --------------------------------------------------------------------------
# ***** BEGIN GPL LICENSE BLOCK *****
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# ***** END GPL LICENCE BLOCK *****
# --------------------------------------------------------------------------

import Blender, webbrowser
version = str(Blender.Get('version'))
webbrowser.open('http://www.blender3d.org/Help/?pg=GettingStarted&ver=' + version)

==> blender-2.49bp1.tgz: share/blender/scripts/help_getting_started.py <==
#!BPY
"""
Name: 'Getting Started'
Blender: 248
Group: 'Help'
Tooltip: 'Help for new users'
"""

__author__ = "Matt Ebb"
__url__ = ("blender", "blenderartists.org")
__version__ = "1.0.1"
__bpydoc__ = """\
This script opens the user's default web browser at www.blender.org's
"Getting Started" page.
"""

# $Id: help_getting_started.py 20071 2009-05-05 21:51:54Z campbellbarton $
#
# --------------------------------------------------------------------------
# Getting Started Help Menu Item
# --------------------------------------------------------------------------
# ***** BEGIN GPL LICENSE BLOCK *****
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# ***** END GPL LICENCE BLOCK *****
# --------------------------------------------------------------------------

import Blender
try: import webbrowser
except: webbrowser = None

if webbrowser:
    webbrowser.open('http://www.blender.org/education-help/tutorials/getting-started/')
else:
    Blender.Draw.PupMenu("Error%t|This script requires a full python installation")
